@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 use 5.006;
 use strict;
 use warnings;
@@ -247,8 +247,6 @@ sub _build_terse {
 		my ($self, $url, $response) = @_;
 		$url = URI->new($url);
 		$url->query_form( $url->query_form, %{$response || {}});
-		use Data::Dumper;
-		warn Dumper $url->as_string;
 		$self->response->status_code = 302;
 		$self->response->message = 'Found';
 		$self->headers->Location = $url->as_string;
@@ -410,7 +408,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
