@@ -152,6 +152,16 @@ sub dispatch {
 	if (!$path && !$req) {
 		$req = lc(ref $self);
 	}
+
+	if ($self->controllers->{_alias}) {
+		for my $candidate (keys %{$self->controllers->{_alias}}) {
+			my @captured = $path =~ m/$candidate/;
+			if (scalar @captured) {
+                                $path = $self->controllers->{_alias}->{$candidate}->{namespace};
+			}
+		}
+	}
+
 	my $controller = $t->controller($path);
 	if ($path && ! $controller) {
 		$t->logError('Path not found - ' . $path, 500);
@@ -186,7 +196,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
